<?php
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class SK_Accordion_Slider_Widget extends Widget_Base {

    public function get_name() {
        return 'accordion-slider';
    }

    public function get_title() {
        return  esc_html__( 'Accordion Slider', 'sliderkits' );
    }

    public function get_icon() {
        return 'eicon-accordion';
    }

    public function get_categories() {
        return array( 'sliderkits' );
    }

    /**
     * Enqueue when widget is on page.
     */
    public function get_style_depends() {
        return array( 'accordion-slider' );
    }
    /**
     * Enqueue scripts when widget is on page.
     */
    public function get_script_depends() {
        return array();
    }

    protected function register_controls() {

      $this->start_controls_section(
          'section_sk_accordion_slider_slides',
          [
              'label' => esc_html__( 'Add Slides', 'sliderkits' ),
              'tab'   => Controls_Manager::TAB_CONTENT,
          ]
      );

      $repeater = new \Elementor\Repeater();

      $repeater->add_control(
        'title', [
          'label' => esc_html__( 'Title', 'sliderkits' ),
          'type' => \Elementor\Controls_Manager::TEXT,
          'default' => esc_html__( 'Long Title' , 'sliderkits' ),
          'label_block' => true,
        ]
      );

      $repeater->add_control(
        'short_title', [
          'label' => esc_html__( 'Short Title', 'sliderkits' ),
          'type' => \Elementor\Controls_Manager::TEXT,
          'default' => esc_html__( 'Short Title' , 'sliderkits' ),
          'label_block' => true,
        ]
      );

      $repeater->add_control(
        'paragraph', [
          'label' => esc_html__( 'Paragraph', 'sliderkits' ),
          'type' => \Elementor\Controls_Manager::TEXTAREA,
          'label_block' => true,
        ]
      );

      $repeater->add_control(
        'link', [
            'label' => esc_html__( 'Link', 'sliderkits' ),
            'type' => Controls_Manager::URL,
            'show_label' => true,
        ]
      );

      $repeater->add_control(
        'picture', [
          'label' => esc_html__( 'Slide Picture', 'sliderkits' ),
          'type' => Controls_Manager::MEDIA,
          'show_label' => false,
          'default' => [
            'url' => \Elementor\Utils::get_placeholder_image_src(),
          ]
        ]
      );

      $repeater->add_control(
        'picture_size', [
          'type' => Controls_Manager::SELECT,
          'label' => esc_html__('Picture Size', 'sliderkits'),
          'default' => 'auto',
          'options' => array(
              'auto' => 'auto',
              '100%' => '100%',
              'cover' => 'cover',
              'contain' => 'contain',
          ),
          'selectors' => [
            '{{WRAPPER}} {{CURRENT_ITEM}}' => 'background-position: {{VALUE}}'
          ]
        ]
      );

      $repeater->add_control(
        'picture_position', [
            'type' => Controls_Manager::SELECT,
            'label' => esc_html__('Picture Position', 'sliderkits'),
            'default' => 'center center',
            'options' => array(
                'top center' => esc_html__( 'Top Center', 'sliderkits' ),
                'top left' => esc_html__( 'Top Left', 'sliderkits' ),
                'top right' => esc_html__( 'Top Right', 'sliderkits' ),
                'center center' => esc_html__( 'Center Center', 'sliderkits' ),
                'center left' => esc_html__( 'Center Left', 'sliderkits' ),
                'center right' => esc_html__( 'Center Right', 'sliderkits' ),
                'bottom center' => esc_html__( 'Bottom Center', 'sliderkits' ),
                'bottom left' => esc_html__( 'Bottom Left', 'sliderkits' ),
                'bottom right' => esc_html__( 'Bottom Right', 'sliderkits' ),
            ),
            'selectors' => [
              '{{WRAPPER}} {{CURRENT_ITEM}}' => 'background-position: {{VALUE}}'
            ]
        ]
      );

      $repeater->add_control(
        'overlay_color', [
            'type' => Controls_Manager::COLOR,
            'label' => esc_html__('Overlay Color', 'sliderkits'),
            'default' => '',
            'selectors' => [
              '{{WRAPPER}} {{CURRENT_ITEM}} .sk-overlay' => 'background-color: {{VALUE}}'
            ]
        ]
      );

      $repeater->add_control(
        'content_style',
        [
          'label' => esc_html__( 'Content Settings', 'sliderkits' ),
          'type' => \Elementor\Controls_Manager::HEADING,
          'separator' => 'before',
        ]
      );

      $repeater->add_control(
          'title_color',
          [
              'type' => Controls_Manager::COLOR,
              'label' => esc_html__( 'Title Color', 'sliderkits' ),
              'default' => '',
              'selectors' => [
                  '{{WRAPPER}} {{CURRENT_ITEM}} .sk-heading span' => 'color: {{VALUE}}'
              ]
          ]
      );

      $repeater->add_group_control(
          Group_Control_Typography::get_type(),
          [
              'name' => 'title_typography',
              'label' => esc_html__( 'Title Typography', 'sliderkits' ),
              'scheme' => Typography::TYPOGRAPHY_2,
              'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .sk-heading span'
          ]
      );

      $repeater->add_control(
          'short_title_color',
          [
              'type' => Controls_Manager::COLOR,
              'label' => esc_html__( 'Short Title Color', 'sliderkits' ),
              'selectors' => [
                  '{{WRAPPER}} {{CURRENT_ITEM}} .sk-heading:before' => 'color: {{VALUE}}'
              ],
          ]
      );

      $repeater->add_group_control(
          Group_Control_Typography::get_type(),
          [
              'name' => 'short_title_typography',
              'label' => esc_html__( 'Short Title Typography', 'sliderkits' ),
              'scheme' => Typography::TYPOGRAPHY_2,
              'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .sk-heading:before'
          ]
      );

      $repeater->add_control(
          'paragraph_color',
          [
              'type' => Controls_Manager::COLOR,
              'label' => esc_html__( 'Paragraph Color', 'sliderkits' ),
              'selectors' => [
                  '{{WRAPPER}} {{CURRENT_ITEM}} .sk-content, {{WRAPPER}} {{CURRENT_ITEM}} .sk-content p' => 'color: {{VALUE}}',
              ]
          ]
      );

      $repeater->add_group_control(
          Group_Control_Typography::get_type(),
          [
              'name' => 'paragraph_typography',
              'label' => esc_html__( 'Paragraph Typography', 'sliderkits' ),
              'scheme' => Typography::TYPOGRAPHY_2,
              'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .sk-content, {{WRAPPER}} {{CURRENT_ITEM}} .sk-content p'
          ]
      );

      $this->add_control(
        'slides',
        [
          'label' => esc_html__( 'Add Slides', 'sliderkits' ),
          'type' => \Elementor\Controls_Manager::REPEATER,
          'fields' => $repeater->get_controls(),
          'default' => [
            [
               'short_title' => '01',
               'title' => 'Hello, SliderKits!',
               'paragraph' => 'Easy to create the slider in Elementor Editor',
               'picture'  => \Elementor\Utils::get_placeholder_image_src()
            ],
            [
               'short_title' => '02',
               'title' => 'Hello, SliderKits!',
               'paragraph' => 'Get quick start with the pre-built slider',
               'picture'  => \Elementor\Utils::get_placeholder_image_src()
            ],
            [
               'short_title' => '03',
               'title' => 'Hello, SliderKits!',
               'paragraph' => 'Easy to create the slider in Elementor Editor',
               'picture'  => \Elementor\Utils::get_placeholder_image_src()
            ],
            [
               'short_title' => '04',
               'title' => 'Hello, SliderKits!',
               'paragraph' => 'Get quick start with the pre-built slider',
               'picture'  => \Elementor\Utils::get_placeholder_image_src()
            ],
            [
               'short_title' => '05',
               'title' => 'Hello, SliderKits!',
               'paragraph' => 'Get quick start with the pre-built slider',
               'picture'  => \Elementor\Utils::get_placeholder_image_src()
            ]
          ],
          'title_field' => '{{{ title }}}',
        ]
      );

      $this->end_controls_section();
    }

    protected function render() {
       SK_Elementor_Widgets::widget_template( self::get_name(),$this->get_settings() );
    }


}
