<?php
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class SK_Blog_Slider_Widget extends Widget_Base {

    public function get_name() {
        return 'blog-slider';
    }

    public function get_title() {
        return  esc_html__( 'Blog Slider', 'sliderkits' );
    }

    public function get_icon() {
        return 'eicon-posts-group';
    }

    public function get_categories() {
        return array( 'sliderkits' );
    }

    public function post_categories() {
      $categories = get_categories( array(
          'orderby' => 'name',
          'order'   => 'ASC'
      ) );

      $data = [];

      foreach( $categories as $category ) {
        $data[$category->term_id] = $category->name;
      }

      return $data;
    }

    public function post_tags() {
      $tags = get_tags();
      $data = [];
      foreach ( $tags as $tag ) {
        $data[$tag->term_id] = $tag->name;
      }
      return $data;
    }

    public function post_list() {
      $args = array(
        'numberposts' => -1
      );

      $posts = get_posts( $args );
      $data = [];

      foreach( $posts as $post ) {
        $data[$post->ID] = $post->post_title;
      }

      return $data;
    }

    /**
     * Enqueue when widget is on page.
     */
    public function get_style_depends() {
        return array( 'slick', 'slick-theme', 'sliderkits', 'blog-slider' );
    }

    protected function register_controls() {
      $this->start_controls_section(
          'section_sk_blog_slider_data_settings',
          [
              'label' => esc_html__( 'Data', 'sliderkits' ),
              'tab'   => Controls_Manager::TAB_CONTENT,
          ]
      );

      $this->add_control(
          'posts_number',
          [
              'label' => esc_html__( 'Number of Posts', 'sliderkits' ),
              'info'  => esc_html__( 'For load speed reason, the maximum number of posts is limited to 6.' ),
              'type' => Controls_Manager::NUMBER,
              'default' => '6',
              'min' => 1,
      				'max' => 6,
      				'step' => 1,
          ]
      );

      $this->add_control(
          'displayas',
          [
              'label' => esc_html__( 'Display As', 'sliderkits' ),
              'type' => Controls_Manager::SELECT,
              'default' => 'all',
              'options' => [
                  'all' => esc_html__( 'All Posts', 'sliderkits' ),
                  'featured' => esc_html__( 'Featured Posts', 'sliderkits' )
              ]
          ]
      );

      $this->add_control(
          'featuredby',
          [
              'label' => esc_html__( 'Featured By', 'sliderkits' ),
              'type' => Controls_Manager::SELECT,
              'default' => 'categories',
              'options' => [
                  'categories' => esc_html__( 'categories', 'sliderkits' ),
                  'tags' => esc_html__( 'tags', 'sliderkits' ),
                  'posts' => esc_html__( 'Specific Posts', 'sliderkits' )
              ],
              'condition' => [
                'displayas' => 'featured'
              ]
          ]
      );

      $this->add_control(
  			'categories',
  			[
  				'label' => esc_html__( 'Select Categories', 'sliderkits' ),
  				'type' => Controls_Manager::SELECT2,
  				'multiple' => true,
  				'options' => $this->post_categories(),
          'condition' => [
            'featuredby' => 'categories'
          ]
  			]
  		);

      $this->add_control(
  			'tags',
  			[
  				'label' => esc_html__( 'Select Tags', 'sliderkits' ),
  				'type' => Controls_Manager::SELECT2,
  				'multiple' => true,
  				'options' => $this->post_tags(),
          'condition' => [
            'featuredby' => 'tags'
          ]
  			]
  		);

      $this->add_control(
  			'posts',
  			[
  				'label' => esc_html__( 'Select Posts', 'sliderkits' ),
  				'type' => Controls_Manager::SELECT2,
  				'multiple' => true,
  				'options' => $this->post_list(),
          'condition' => [
            'featuredby' => 'posts'
          ]
  			]
  		);

      $this->add_control(
          'orderby',
          [
              'label' => esc_html__( 'Order By', 'sliderkits' ),
              'type' => Controls_Manager::SELECT,
              'default' => 'date',
              'options' => [
                  'date' => esc_html__( 'Date', 'sliderkits' ),
                  'title' => esc_html__( 'Title', 'sliderkits' ),
                  'rand' => esc_html__( 'Random', 'sliderkits' )
              ]
          ]
      );

      $this->add_control(
          'order',
          [
              'label' => esc_html__( 'Order', 'sliderkits' ),
              'type' => Controls_Manager::SELECT,
              'default' => 'DESC',
              'options' => [
                  'DESC' => esc_html__( 'DESC', 'sliderkits' ),
                  'ASC' => esc_html__( 'ASC', 'sliderkits' )
              ]
          ]
      );

      $this->add_control(
          'button_text',
          [
              'label' => esc_html__( 'Button Text', 'sliderkits' ),
              'type' => Controls_Manager::TEXT,
              'default' => 'Read More'
          ]
      );

      $this->end_controls_section();

      $this->start_controls_section(
          'section_sk_blog_slider_settings',
          [
              'label' => esc_html__( 'Slider Setting', 'sliderkits' ),
              'tab'   => Controls_Manager::TAB_CONTENT,
          ]
      );

      $this->add_control(
          'autoplay',
          [
              'label' => esc_html__( 'Autoplay', 'sliderkits' ),
              'type' => Controls_Manager::SWITCHER,
              'default' => 'false',
              'label_on' => esc_html__( 'Yes', 'sliderkits' ),
              'label_off' => esc_html__( 'No', 'sliderkits' ),
              'return_value' => 'true',
          ]
      );

      $this->add_control(
          'autoplaySpeed',
          [
              'label' => esc_html__( 'Autoplay Speed', 'sliderkits' ),
              'type' => Controls_Manager::NUMBER,
              'default' => '3000',
              'condition' => [
                  'autoplay' => 'true',
              ]
          ]
      );

      $this->add_control(
          'pauseOnHover',
          [
              'label' => esc_html__( 'Pause On Hover', 'sliderkits' ),
              'type' => Controls_Manager::SWITCHER,
              'default' => 'true',
              'label_on' => esc_html__( 'Yes', 'sliderkits' ),
              'label_off' => esc_html__( 'No', 'sliderkits' ),
              'return_value' => 'true',
              'condition' => [
                  'autoplay' => 'true',
              ]
          ]
      );

      $this->add_control(
          'arrows',
          [
              'label' => esc_html__( 'Arrows', 'sliderkits' ),
              'type' => Controls_Manager::SWITCHER,
              'default' => 'true',
              'label_on' => esc_html__( 'Yes', 'sliderkits' ),
              'label_off' => esc_html__( 'No', 'sliderkits' ),
              'return_value' => 'true'
          ]
      );

      $this->add_control(
          'infinite',
          [
              'label' => esc_html__( 'Infinite Loop', 'sliderkits' ),
              'type' => Controls_Manager::SWITCHER,
              'default' => 'false',
              'label_on' => esc_html__( 'Yes', 'sliderkits' ),
              'label_off' => esc_html__( 'No', 'sliderkits' ),
              'return_value' => 'true'
          ]
      );

      $this->add_control(
          'swipe',
          [
              'label' => esc_html__( 'Touch Swipe', 'sliderkits' ),
              'type' => Controls_Manager::SWITCHER,
              'default' => 'true',
              'label_on' => esc_html__( 'Yes', 'sliderkits' ),
              'label_off' => esc_html__( 'No', 'sliderkits' ),
              'return_value' => 'true'
          ]
      );

      $this->add_control(
          'touchMove',
          [
              'label' => esc_html__( 'Slide moving with touch', 'sliderkits' ),
              'type' => Controls_Manager::SWITCHER,
              'default' => 'true',
              'label_on' => esc_html__( 'Yes', 'sliderkits' ),
              'label_off' => esc_html__( 'No', 'sliderkits' ),
              'return_value' => 'true'
          ]
      );

      $this->add_control(
          'speed',
          [
              'label' => esc_html__( 'Transition Speed', 'sliderkits' ),
              'type' => Controls_Manager::NUMBER,
              'default' => '300'
          ]
      );

      $this->end_controls_section();

      $this->start_controls_section(
          'section_sk_blog_slider_content_style',
          [
              'label' => esc_html__( 'Content', 'sliderkits' ),
              'tab'   => Controls_Manager::TAB_STYLE,
          ]
      );

      $this->add_control(
          'title_color',
          [
              'type' => Controls_Manager::COLOR,
              'label' => esc_html__( 'Title Color', 'sliderkits' ),
              'default' => '',
              'selectors' => [
                  '{{WRAPPER}} .sk-slick-item .sk-heading' => 'color: {{VALUE}}',
              ],
          ]
      );

      $this->add_group_control(
          Group_Control_Typography::get_type(),
          [
              'name' => 'title_typography',
              'label' => esc_html__( 'Title Typography', 'sliderkits' ),
              'scheme' => Typography::TYPOGRAPHY_2,
              'selector' => '{{WRAPPER}} .sk-slick-item .sk-heading'
          ]
      );

      $this->add_control(
          'paragraph_color',
          [
              'type' => Controls_Manager::COLOR,
              'label' => esc_html__( 'Paragraph Color', 'sliderkits' ),
              'selectors' => [
                  '{{WRAPPER}} .sk-slick-item .sk-content, {{WRAPPER}} .sk-slick-item .sk-content p' => 'color: {{VALUE}}',
              ]
          ]
      );

      $this->add_group_control(
          Group_Control_Typography::get_type(),
          [
              'name' => 'paragraph_typography',
              'label' => esc_html__( 'Paragraph Typography', 'sliderkits' ),
              'scheme' => Typography::TYPOGRAPHY_2,
              'selector' => '{{WRAPPER}} .sk-slick-item .sk-content, {{WRAPPER}} .sk-slick-item .sk-content p'
          ]
      );

      $this->end_controls_section();

      $this->start_controls_section(
          'section_sk_blog_slider_button',
          [
              'label' => esc_html__('Button', 'sliderkits'),
              'tab'   => Controls_Manager::TAB_STYLE,
          ]
      );

      $this->add_group_control(
          Group_Control_Typography::get_type(),
          [
              'name' => 'button_typography',
              'scheme' => Typography::TYPOGRAPHY_2,
              'selector' => '{{WRAPPER}} .elementor-button.sk-button',
          ]
      );

      $this->start_controls_tabs( 'tabs_button_style' );

      $this->start_controls_tab(
          'tab_button_normal',
          [
              'label' => esc_html__( 'Normal', 'sliderkits' ),
          ]
      );

      $this->add_control(
          'button_text_color',
          [
              'label' => esc_html__( 'Text Color', 'sliderkits' ),
              'type' => Controls_Manager::COLOR,
              'default' => '',
              'selectors' => [
                  '{{WRAPPER}} .elementor-button.sk-button' => 'fill: {{VALUE}}; color: {{VALUE}};',
              ],
          ]
      );

      $this->add_control(
          'button_background_color',
          [
              'label' => esc_html__( 'Background Color', 'sliderkits' ),
              'type' => Controls_Manager::COLOR,
              'selectors' => [
                  '{{WRAPPER}} .elementor-button.sk-button' => 'background-color: {{VALUE}};',
              ],
          ]
      );

      $this->add_group_control(
          Group_Control_Border::get_type(),
          [
              'name' => 'button_border',
              'selector' => '{{WRAPPER}} .elementor-button.sk-button',
              'separator' => 'before',
          ]
      );

      $this->end_controls_tab();

      $this->start_controls_tab(
          'tab_button_hover',
          [
              'label' => esc_html__( 'Hover', 'sliderkits' ),
          ]
      );

      $this->add_control(
          'button_hover_color',
          [
              'label' => esc_html__( 'Text Color', 'sliderkits' ),
              'type' => Controls_Manager::COLOR,
              'selectors' => [
                  '{{WRAPPER}} .elementor-button.sk-button:hover' => 'color: {{VALUE}};'
              ],
          ]
      );

      $this->add_control(
          'button_background_hover_color',
          [
              'label' => esc_html__( 'Background Color', 'sliderkits' ),
              'type' => Controls_Manager::COLOR,
              'selectors' => [
                  '{{WRAPPER}} .elementor-button.sk-button:hover' => 'background-color: {{VALUE}};',
              ],
          ]
      );

      $this->add_control(
          'button_hover_border_color',
          [
              'label' => esc_html__( 'Border Color', 'sliderkits' ),
              'type' => Controls_Manager::COLOR,
              'condition' => [
                  'border_border!' => '',
              ],
              'selectors' => [
                  '{{WRAPPER}} .elementor-button.sk-button:hover' => 'border-color: {{VALUE}};',
              ],
          ]
      );

      $this->add_control(
          'button_hover_animation',
          [
              'label' => esc_html__( 'Hover Animation', 'sliderkits' ),
              'type' => Controls_Manager::HOVER_ANIMATION,
          ]
      );

      $this->end_controls_tab();

      $this->end_controls_tabs();

      $this->add_control(
          'button_border_radius',
          [
              'label' => esc_html__( 'Border Radius', 'sliderkits' ),
              'type' => Controls_Manager::DIMENSIONS,
              'size_units' => [ 'px', '%' ],
              'selectors' => [
                  '{{WRAPPER}} .elementor-button.sk-button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
              ],
          ]
      );

      $this->add_group_control(
          Group_Control_Box_Shadow::get_type(),
          [
              'name' => 'button_box_shadow',
              'selector' => '{{WRAPPER}} .elementor-button.sk-button',
          ]
      );

      $this->add_responsive_control(
          'button_text_padding',
          [
              'label' => esc_html__( 'Padding', 'sliderkits' ),
              'type' => Controls_Manager::DIMENSIONS,
              'size_units' => [ 'px', 'em', '%' ],
              'selectors' => [
                  '{{WRAPPER}} .elementor-button.sk-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
              ],
              'separator' => 'before',
          ]
      );

      $this->end_controls_section();

      $this->start_controls_section(
          'section_sk_blog_slider_arrows',
          [
              'label' => esc_html__('Arrows', 'sliderkits'),
              'tab'   => Controls_Manager::TAB_STYLE,
          ]
      );

      $this->add_responsive_control(
          'arrows_color',
          [
              'type' => Controls_Manager::COLOR,
              'label' => esc_html__( 'Arrows Color', 'sliderkits' ),
              'default' => '#fff',
              'selectors' => [
                  '{{WRAPPER}} .slick-prev:before, {{WRAPPER}} .slick-next:before' => 'color: {{VALUE}}',
              ],
              'condition' => [
                  'arrows' => 'true',
              ]
          ]
      );

      $this->add_responsive_control(
        'arrow_size',
        [
          'label' => esc_html__( 'Arrow Size', 'sliderkits' ),
          'type' => Controls_Manager::SLIDER,
          'size_units' => [ 'px' ],
          'range' => [
            'px' => [
              'min' => 20,
              'max' => 100,
              'step' => 1,
            ]
          ],
          'default' => [
            'unit' => 'px',
            'size' => 50,
          ],
          'condition' => [
              'arrows' => 'true',
          ],
          'selectors' => [
            '{{WRAPPER}} .slick-prev:before, {{WRAPPER}} .slick-next:before' => 'font-size: {{SIZE}}{{UNIT}};',
          ],
        ]
      );

      $this->add_control(
        'arrow_disabled',
        [
          'label' => esc_html__( 'Arrows Disabled',  ),
          'show_label' => false,
          'type' => \Elementor\Controls_Manager::RAW_HTML,
          'raw' => esc_html__( 'The arrows are disabled.', 'sliderkits' ),
          'conditions' => [
              'relation' => 'and',
              'terms' => [
                  [
                      'name' => 'arrows',
                      'operator' => '!==',
                      'value' => 'true'
                  ]
              ]
          ]
        ]
      );
      $this->end_controls_section();

      $this->start_controls_section(
          'section_sk_blog_slider_overlay',
          [
              'label' => esc_html__('Overlay', 'sliderkits'),
              'tab'   => Controls_Manager::TAB_STYLE,
          ]
      );

      $this->add_responsive_control(
          'overlay_color',
          [
              'type' => Controls_Manager::COLOR,
              'label' => esc_html__( 'Overlay Color', 'sliderkits' ),
              'default' => '',
              'selectors' => [
                  '{{WRAPPER}} .sk-slick-item__overlay' => 'background-color: {{VALUE}}',
              ]
          ]
      );
      $this->end_controls_section();
    }

    protected function render() {
       SK_Elementor_Widgets::widget_template( self::get_name(),$this->get_settings() );
       if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) {
           echo '<script>window.SliderKits.init();</script>';
       }
    }

}
